import sys
import foo
import py.test


def test_isInt():
    assert True == foo.isInt(0)
    assert False == foo.isInt("not an int")


def test_makeList():
    assert [1,2,3] == foo.makeList(1, 2, 3)


def test_divide():
    assert 0 == foo.divide(0, 1)

    # Dividing 1 by 0 should raise
    # ZeroDivisionError
    py.test.raises(
        ZeroDivisionError, foo.divide, 1, 0)


class DummyConnection(object):
    def close(self):
        pass


def create_db_connection():
    return DummyConnection()


# Using funcargs instead of setup/teardown for the db connection
def pytest_funcarg__db(request):
    db = create_db_connection()
    request.addfinalizer(lambda: db.close())
    return db


def test_db(db):
    # ... do something ...
    assert isinstance(db, DummyConnection)


# A test marked as "expected failure"
@py.test.mark.xfail
def test_xfail():
    assert 0 == 1


# A test marked with keyword "nothing"
@py.test.mark(nothing=True)
def test_zero_equals_zero():
    assert 0 == 0


class TestWin32Only:
    disabled = sys.platform != 'win32'

    def test_true(self):
        assert True


# Generative test cases

# Old style
def test_generative():
    for i in xrange(0,20,2):
        yield check_even, i


def check_even(even_number):
    assert True == foo.isEven(even_number)
    assert False == foo.isEven(even_number+1)


def pytest_generate_tests(metafunc):
    if "even_number" in metafunc.funcargnames:
        for i in xrange(0,20,2):
            # It's a good idea to set the id, so 
            # you have some idea of which test
            # case failed
            metafunc.addcall(
                id=str(i),
                funcargs=dict(even_number=i))


def test_even(even_number):
    assert True == foo.isEven(even_number)
    assert False == foo.isEven(even_number+1)

